#!/usr/bin/python3
# -*- coding: UTF-8 -*-
#
#   commTee.py
#
#       command実行とfile出力を行う
#       linuxの場合はteeコマンドがあるが、windowsの場合は無い為作成。
#
#       commTee.py <command> <arg1> <arg2> ... <fileName>
#
#   19/01/29    新規作成
#   22/03/14    国際化
#      04/25    connTeeAdd:追加
#

import sys, os
import subprocess

import gettext
localeDir = os.getenv("LOCALE_DIR")
gettext.install("easyistr", localeDir)

def printHelp():
    cont = """
----- <commTee.py> ---------------------------------------------------------
command実行とその出力をfileに出力する。
windowsでは、teeコマンドが無いため、その代用。

<使い方>
commTee.py [option] <command> [<args1> <args2> ...] <fileName>
  option
    -a          :fileに追加して出力する
  command       :実行するコマンド
  args1 ...     :コマンドの引数（省略可）
  fileName      :コマンドが出力する内容を保存するfileName

<例>
commTee.py dir test.txt
commTee.py -a dir test.txt      #test.txtに追加して出力する
"""
    print (cont)

def commTee(comms):
    comm = " ".join(comms)
    proc = subprocess.Popen(
            comm,
            shell=True,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE)
    for line in iter(proc.stdout.readline, b""):
        line = line.decode("utf-8")
        print (line, end="")
        if line[-2:] == "\r\n":
            line = line[:-2] + "\n"
        f.write(line)
        f.flush()
    #実行結果を確認
    errCont = proc.stderr.read().decode("utf-8")
    if errCont != "":
        print(errCont)
        f.write(errCont)
        f.flush()

def commTeeAdd(comms):
    """ logをfileに追加してcommを実行する。"""
    comm = " ".join(comms)
    proc = subprocess.Popen(
            comm,
            shell=True,
            stdout=subprocess.PIPE,
            stderr=subprocess.PIPE)
    #実行結果を行単位で取得
    for line in iter(proc.stdout.readline, b""):
        line = line.decode("utf-8")
        print (line, end="")
        if line[-2:] == "\r\n":
            line = line[:-2] + "\n"
        f.write(line)
        f.flush()
    #実行結果を確認
    errCont = proc.stderr.read().decode("utf-8")
    if errCont != "":
        print(errCont)
        f.write(errCont)
        f.flush()

if __name__ == "__main__":
    if len(sys.argv) <= 2:
        print (_(u"引数が不足しています"))
        printHelp()
        exit()
    comms = sys.argv[1:-1]
    outFile = sys.argv[-1]
    #fileに追加して出力？
    if comms[0] == "-a" or comms[0] == "--add":
        comms = comms[1:]
        f = open(outFile, "a", encoding="utf-8")
        try:
            commTeeAdd(comms)
        except KeyboardInterrupt:
            pass
        finally:
            f.close()
    else:
        #引数エラー
        if comms[0][0] == "-":
            printHelp()
            exit()
        #結果をfileに出力する
        f = open(outFile, "w", encoding="utf-8")
        try:
            commTee(comms)
        except KeyboardInterrupt:
            pass
        finally:
            f.close()

