#!/usr/bin/python3
#  coding :  utf-8
#
#       editUsingAppDDialog.py
#
#       usingAppファイルを編集する。
#
#   20/07/07    新規作成
#      07/08    CAD, mesherを追加
#      07/10    writeUsingApp:usingAppの書き込みをutf-8に指定した。
#               windowsでは、shift-jisになってしまう為。
#   22/03/13    languageの設定を追加
#      03/22    国際化（文字をpython側でセット）
#      03/24    setTextToUsingApp:dialog表示を追加。
#

import gi
gi.require_version("Gtk", "3.0")
from gi.repository import Gtk

import sys   
import os   

import pyFistr
import GtkParts

#import locale
#gladeファイル内を翻訳
localeDir = os.getenv("LOCALE_DIR")
#locale.bindtextdomain("easyistr", localeDir)

ls = "\n"


#----------------------
#  windowApp class
#----------------------
class windowApp:

    def __init__(self):
        self.builder = Gtk.Builder()
        #self.builder.set_translation_domain("easyistr")
        self.builder.add_from_file(os.path.dirname(os.path.abspath(__file__)) + os.sep + "editUsingAppDialog.glade")
        self.mainWindow = self.builder.get_object("window1")
        self.mainWindow.connect("delete-event", self.close)
        self.builder.connect_signals(self)
        self.setGtkObject()
        self.mainWindow.set_title(_("設定内容の変更"))
        self.stat = "CANCEL"
        self.usingAppDict = {}

    #
    #  show
    #-------
    def show(self):
        self.initialize()
        #self.mainWindow.show_all()
        self.mainWindow.show()
        Gtk.main()
        return self.stat

    #
    #  close
    #--------
    def close(self, *args):
        #Gtk.main_quit(*args)
        self.mainWindow.destroy()
        Gtk.main_quit(*args)

    #
    #  setGtkObject
    #---------------
    def setGtkObject(self):
        self.entry_terminal = self.builder.get_object("entry_terminal")
        self.entry_fileManager = self.builder.get_object("entry_fileManager")
        self.entry_editor = self.builder.get_object("entry_editor")
        self.entry_fistrFolder = self.builder.get_object("entry_fistrFolder")
        self.entry_paraView = self.builder.get_object("entry_paraView")
        self.entry_office = self.builder.get_object("entry_office")
        self.entry_REVOCAP = self.builder.get_object("entry_REVOCAP")
        self.entry_gnuplot = self.builder.get_object("entry_gnuplot")
        self.entry_cad = self.builder.get_object("entry_cad")
        self.entry_mesher = self.builder.get_object("entry_mesher")
        self.combo_language = self.builder.get_object("combo_language")
        #文字をセット
        self.builder.get_object("label_subTitle").set_text(_("usingAppファイル内容の編集"))
        self.builder.get_object("label_setConts").set_text(_("設定内容"))
        self.builder.get_object("label_term").set_text(_("端末"))
        self.builder.get_object("label_fistr").set_text(_("FrontISTR実行ファイル保存場所"))
        self.builder.get_object("label_forCheckRes").set_text(_("結果確認用"))
        self.builder.get_object("label_forEditCsv").set_text(_("csvファイル編集用"))
        self.builder.get_object("label_forResidual").set_text(_("残渣確認用"))
        self.builder.get_object("label_forModelCad").set_text(_("CAD model作成用"))
        self.builder.get_object("label_forMesh").set_text(_("mesh作成用"))
        self.builder.get_object("button_cancel").get_child().set_text(_("キャンセル"))
        self.builder.get_object("button_apply").get_child().set_text(_("適用"))

    #
    #  event handler --------------------------
    #キャンセル
    def onCancel(self, event):
        self.stat = "CANCEL"
        self.close()
    #適用
    def onApply(self, event):
        self.setTextToUsingApp()
        self.stat = "OK"
        self.close()

    #
    #  setTextToUsingApp
    #--------------------
    def setTextToUsingApp(self):
        """ GUIのentryから内容を取得し、usingAppに書き込み"""
        lang = self.comboLang.getSelectedItem()
        office = self.entry_office.get_text()
        terminal = self.entry_terminal.get_text()
        fileManager = self.entry_fileManager.get_text()
        editor = self.entry_editor.get_text()
        frontIstrFolder = self.entry_fistrFolder.get_text()
        paraView = self.entry_paraView.get_text()
        revocap = self.entry_REVOCAP.get_text()
        gnuplot = self.entry_gnuplot.get_text()
        cad = self.entry_cad.get_text()
        mesher = self.entry_mesher.get_text()
        appDict = {}
        appDict["language"] = lang
        appDict["office"] = office
        appDict["terminal"] = terminal
        appDict["fileManager"] = fileManager
        appDict["editor"] = editor
        appDict["frontIstrFolder"] = frontIstrFolder
        appDict["paraView"] = paraView
        appDict["REVOCAP"] = revocap
        appDict["gnuplot"] = gnuplot
        appDict["CAD"] = cad
        appDict["mesher"] = mesher
        #usingAppに書き込み
        writeUsingApp(appDict)
        #dialogを表示
        title = _("usingAppの設定")
        mess = _("usingAppファイル内容を書き換えました。")
        if self.usingAppDict["language"] != appDict["language"]:
            mess += ls + ls + _("使用言語が変更されています。") + ls
            mess += "    " + _("言語の変更は、次回起動時に適用されます。")
        self.okDialog(title, mess)

    #
    #  initialize
    #---------------
    def initialize(self):
        #usingAppの読み込み
        appDict = pyFistr.readUsingApplications()
        self.usingAppDict = appDict
        #comboにセット
        self.comboLang = GtkParts.comboBox(self.combo_language)
        items = ["Japanese", "English"]
        self.comboLang.setItems(items)
        lang = appDict["language"]
        self.comboLang.selectItem(lang)
        #entryにセット
        self.entry_office.set_text(appDict["office"])
        self.entry_terminal.set_text(appDict["terminal"])
        self.entry_fileManager.set_text(appDict["fileManager"])
        self.entry_editor.set_text(appDict["editor"])
        self.entry_fistrFolder.set_text(appDict["frontIstrFolder"])
        self.entry_paraView.set_text(appDict["paraView"])
        self.entry_REVOCAP.set_text(appDict["REVOCAP"])
        self.entry_gnuplot.set_text(appDict["gnuplot"])
        self.entry_cad.set_text(appDict["CAD"])
        self.entry_mesher.set_text(appDict["mesher"])
        
    #
    #  okDialog
    def okDialog(self, title, message):
        dlg = Gtk.MessageDialog(
                parent=self.mainWindow,
                message_type=Gtk.MessageType.INFO,
                buttons=Gtk.ButtonsType.OK)
        dlg.set_title(title)
        #messageを分ける
        mess1 = message.split(ls)[0]
        mess2 = ls.join(message.split(ls)[1:])
        dlg.set_markup(mess1)
        dlg.format_secondary_text(mess2)
        dlg.run()
        dlg.destroy()
    

#
#  writeUsingApp
#-----------------
def writeUsingApp(appDict):
    """ usingAppにappDictを書き込み"""
    pyFistr.writeUsingApplications(appDict)


if __name__ == "__main__":
    import gettext
    #gettext.install("app")
    #_ = gettext.gettext
    gettext.install("easyistr", localeDir)

    app = windowApp()
    app.main()


